@@ -2,7 +2,7 @@ package Spork::Formatter::TKSlide;
 use strict;
 use Spoon::Formatter '-base';
 
-field const top_class => 'Spork::Formatter::TKSlide::Top';
+const top_class => 'Spork::Formatter::TKSlide::Top';
 
 sub formatter_classes {
     map { "Spork::Formatter::TKSlide::$_" } qw(
@@ -81,14 +81,14 @@ sub to_html {
 ################################################################################
 package Spork::Formatter::TKSlide::Top;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'top';
-field const contains_blocks => [qw(header ul1 ol1 pre p)];
+const formatter_id => 'top';
+const contains_blocks => [qw(header ul1 ol1 pre p)];
 
 ################################################################################
 package Spork::Formatter::TKSlide::Header;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'header';
-field const contains_phrases => [qw(b i u tt)];
+const formatter_id => 'header';
+const contains_phrases => [qw(b i u tt)];
 field 'level'; 
 
 sub to_html {
@@ -115,10 +115,10 @@ sub match {
 ################################################################################
 package Spork::Formatter::TKSlide::Paragraph;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'p';
-field const html_start => "<p>\n";
-field const html_end => "</p>\n";
-field const contains_phrases => [qw(b i u tt hyper file image)];
+const formatter_id => 'p';
+const html_start => "<p>\n";
+const html_end => "</p>\n";
+const contains_phrases => [qw(b i u tt hyper file image)];
 
 sub match {
     my $self = shift;
@@ -129,10 +129,10 @@ sub match {
 ################################################################################
 package Spork::Formatter::TKSlide::Ulist;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'ul';
-field const html_start => "<ul>\n";
-field const html_end => "</ul>\n";
-field const level => 1;
+const formatter_id => 'ul';
+const html_start => "<ul>\n";
+const html_end => "</ul>\n";
+const level => 1;
 
 sub match {
     my $self = shift;
@@ -150,16 +150,16 @@ for my $level (1..4) {
     eval <<END; die $@ if $@;
 package Spork::Formatter::TKSlide::Ulist$level;
 use base 'Spork::Formatter::TKSlide::Ulist';
-field const formatter_id => 'ul$level';
-field const level => $level;
-field const contains_blocks => [qw($list)];
+const formatter_id => 'ul$level';
+const level => $level;
+const contains_blocks => [qw($list)];
 END
 }
 
 ################################################################################
 package Spork::Formatter::TKSlide::Olist;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'ol';
+const formatter_id => 'ol';
 field html_start => "<ol>\n";
 field html_end => "</ol>\n";
 
@@ -179,18 +179,18 @@ for my $level (1..4) {
     eval <<END; die $@ if $@;
 package Spork::Formatter::TKSlide::Olist$level;
 use base 'Spork::Formatter::TKSlide::Olist';
-field const formatter_id => 'ol$level';
-field const level => $level;
-field const contains_blocks => [qw($list)];
+const formatter_id => 'ol$level';
+const level => $level;
+const contains_blocks => [qw($list)];
 END
 }
 
 ################################################################################
 package Spork::Formatter::TKSlide::Item;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const html_start => "<li>";
-field const html_end => "</li>\n";
-field const contains_phrases => [qw(hyper b i u tt hyper file image)];
+const html_start => "<li>";
+const html_end => "</li>\n";
+const contains_phrases => [qw(hyper b i u tt hyper file image)];
 
 sub match {
     my $self = shift;
@@ -215,15 +215,15 @@ for my $level (1..4) {
     eval <<END; die $@ if $@;
 package Spork::Formatter::TKSlide::Item$level;
 use base 'Spork::Formatter::TKSlide::Item';
-field const formatter_id => 'li$level';
-field const level => $level;
+const formatter_id => 'li$level';
+const level => $level;
 END
 }
 
 ################################################################################
 package Spork::Formatter::TKSlide::Preformatted;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'pre';
+const formatter_id => 'pre';
 
 sub match {
     my $self = shift;
@@ -255,49 +255,49 @@ sub to_html {
 ################################################################################
 package Spork::Formatter::TKSlide::Bold;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'b';
-field const html_start => "<b>";
-field const html_end => "</b>";
+const formatter_id => 'b';
+const html_start => "<b>";
+const html_end => "</b>";
 # field const contains_phrases => [qw(i u tt href mail wiki)];
-field const contains_phrases => [qw(i u tt)]; #XXX
-field const pattern_start => qr/(^|(?<=\s))\*(?=\S)/;
-field const pattern_end => qr/\*(?=\W|\z)/;
+const contains_phrases => [qw(i u tt)]; #XXX
+const pattern_start => qr/(^|(?<=\s))\*(?=\S)/;
+const pattern_end => qr/\*(?=\W|\z)/;
 
 ################################################################################
 package Spork::Formatter::TKSlide::Italic;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'i';
-field const html_start => "<i>";
-field const html_end => "</i>";
-field const contains_phrases => [qw(b u tt)];
-field const pattern_start => qr/(^|(?<=\s))\/(?=\S)/;
-field const pattern_end => qr/\/(?=\W|\z)/;
+const formatter_id => 'i';
+const html_start => "<i>";
+const html_end => "</i>";
+const contains_phrases => [qw(b u tt)];
+const pattern_start => qr/(^|(?<=\s))\/(?=\S)/;
+const pattern_end => qr/\/(?=\W|\z)/;
 
 ################################################################################
 package Spork::Formatter::TKSlide::Underline;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'u';
-field const html_start => "<u>";
-field const html_end => "</u>";
+const formatter_id => 'u';
+const html_start => "<u>";
+const html_end => "</u>";
 # field const contains_phrases => [qw(b u tt href mail wiki)];
-field const contains_phrases => [qw(b i tt)]; #XXX
-field const pattern_start => qr/(^|(?<=\s))_(?=\S)/;
-field const pattern_end => qr/_(?=\W|\z)/;
+const contains_phrases => [qw(b i tt)]; #XXX
+const pattern_start => qr/(^|(?<=\s))_(?=\S)/;
+const pattern_end => qr/_(?=\W|\z)/;
 
 ################################################################################
 package Spork::Formatter::TKSlide::Inline;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'tt';
-field const html_start => qq{<tt style="font-size:13">};
-field const html_end => "</tt>";
-field const pattern_start => qr/(^|(?<=\s))\|(?=\S)/;
-field const pattern_end => qr/(?!<\\)\|(?=\W|\z)/;
+const formatter_id => 'tt';
+const html_start => qq{<tt style="font-size:13">};
+const html_end => "</tt>";
+const pattern_start => qr/(^|(?<=\s))\|(?=\S)/;
+const pattern_end => qr/(?!<\\)\|(?=\W|\z)/;
 
 ################################################################################
 package Spork::Formatter::TKSlide::HyperLink;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'hyper';
-field const pattern_start => qr/http:\/\/\S+/;
+const formatter_id => 'hyper';
+const pattern_start => qr/http:\/\/\S+/;
 
 sub html_start {
     my $self = shift;
@@ -309,9 +309,9 @@ sub html_start {
 ################################################################################
 package Spork::Formatter::TKSlide::File;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'file';
-field const pattern_start => qr/(^|(?<=\s))file</;
-field const pattern_end => qr/>/;
+const formatter_id => 'file';
+const pattern_start => qr/(^|(?<=\s))file</;
+const pattern_end => qr/>/;
 field 'link_file';
 field 'link_text';
 
@@ -339,9 +339,9 @@ sub html_start {
 ################################################################################
 package Spork::Formatter::TKSlide::Image;
 use base 'Spork::Formatter::TKSlide::Unit';
-field const formatter_id => 'image';
-field const pattern_start => qr/(^|(?<=\s))image</;
-field const pattern_end => qr/>/;
+const formatter_id => 'image';
+const pattern_start => qr/(^|(?<=\s))image</;
+const pattern_end => qr/>/;
 
 sub to_html {
     my $self = shift;
